.. _ext-backends:

******************
Backend extensions
******************

Here you can find a list of external packages that extend Mopidy with
additional music sources by implementing the :ref:`backend-api`.

This list is moderated and updated on a regular basis. If you want your package
to show up here, follow the :ref:`guide on creating extensions <extensiondev>`.


Mopidy-Banshee
==============

https://github.com/tamland/mopidy-banshee

Provides a backend for playing music from the `Banshee <http://banshee.fm/>`_
music player's music library.


Mopidy-Bassdrive
================

https://github.com/felixb/mopidy-Bassdrive

Provides a backend for playing radio streams from `BassDrive
<http://bassdrive.com/>`_.


Mopidy-Beets
============

https://github.com/mopidy/mopidy-beets

Provides a backend for playing music from your `Beets
<http://beets.radbox.org/>`_ music library through Beets' web extension.


Mopidy-Dirble
=============

https://github.com/mopidy/mopidy-dirble

Provides a backend for browsing the Internet radio channels from the `Dirble
<http://dirble.com/>`_ directory.


Mopidy-GMusic
=============

https://github.com/hechtus/mopidy-gmusic

Provides a backend for playing music from `Google Play Music
<https://play.google.com/music/>`_.


Mopidy-InternetArchive
======================

https://github.com/tkem/mopidy-internetarchive

Extension for playing music and audio from the `Internet Archive
<https://archive.org/>`_.


Mopidy-LeftAsRain
=================

https://github.com/naglis/mopidy-leftasrain

Extension for playing music from the `leftasrain.com
<http://leftasrain.com/>`_ music blog.


Mopidy-Local
============

Bundled with Mopidy. See :ref:`ext-local`.


Mopidy-Podcast
==============

https://github.com/tkem/mopidy-podcast

Extension for browsing RSS feeds of podcasts and stream the episodes.


Mopidy-Podcast-gpodder.net
==========================

https://github.com/tkem/mopidy-podcast-gpodder

Extension for Mopidy-Podcast that lets you search and browse podcasts from the
`gpodder.net <https://gpodder.net/>`_ web site.


Mopidy-Podcast-iTunes
=====================

https://github.com/tkem/mopidy-podcast-itunes

Extension for Mopidy-Podcast that lets you search and browse podcasts from the
Apple iTunes Store.


Mopidy-Podcast-gpodder.net
==========================

https://github.com/tkem/mopidy-podcast-gpodder

Extension for Mopidy-Podcast that lets you search and browse podcasts from the
`gpodder.net <https://gpodder.net/>`_ web site.


Mopidy-Podcast-iTunes
=====================

https://github.com/tkem/mopidy-podcast-itunes

Extension for Mopidy-Podcast that lets you search and browse podcasts from the
Apple iTunes Store.


Mopidy-radio-de
===============

https://github.com/hechtus/mopidy-radio-de

Extension for listening to Internet radio stations and podcasts listed at
`radio.de <http://www.radio.de/>`_, `rad.io <http://www.rad.io/>`_,
`radio.fr <http://www.radio.fr/>`_, and `radio.at <http://www.radio.at/>`_.


Mopidy-SomaFM
=============

https://github.com/AlexandrePTJ/mopidy-somafm

Provides a backend for playing music from the `SomaFM <http://somafm.com/>`_
service.


Mopidy-SoundCloud
=================

https://github.com/mopidy/mopidy-soundcloud

Provides a backend for playing music from the `SoundCloud
<http://www.soundcloud.com/>`_ service.


Mopidy-Spotify
==============

https://github.com/mopidy/mopidy-spotify

Extension for playing music from the `Spotify <http://www.spotify.com/>`_ music
streaming service.


Mopidy-Spotify-Tunigo
=====================

https://github.com/trygveaa/mopidy-spotify-tunigo

Extension for providing the browse feature of `Spotify
<http://www.spotify.com/>`_. This lets you browse playlists, genres and new
releases.


Mopidy-Stream
=============

Bundled with Mopidy. See :ref:`ext-stream`.


Mopidy-Subsonic
===============

https://github.com/rattboi/mopidy-subsonic

Provides a backend for playing music from a `Subsonic Music Streamer
<http://www.subsonic.org/>`_ library.


Mopidy-TuneIn
=============

https://github.com/kingosticks/mopidy-tunein

Provides a backend for playing music from the `TuneIn
<http://www.tunein.com/>`_ online radio service.


Mopidy-VKontakte
================

https://github.com/sibuser/mopidy-vkontakte

Provides a backend for playing music from the `VKontakte social network
<http://vk.com/>`_.


Mopidy-YouTube
==============

https://github.com/dz0ny/mopidy-youtube

Provides a backend for playing music from the `YouTube
<http://www.youtube.com/>`_ service.
